@@ -114,9 +114,7 @@ def _decode_mixins(tbl):
 
     # Construct new table with mixins, using tbl.meta['__serialized_columns__']
     # as guidance.
-    tbl = serialize._construct_mixins_from_columns(tbl)
-
-    return tbl
+    return serialize._construct_mixins_from_columns(tbl)
 
 
 def read_table_fits(
@@ -128,6 +126,8 @@ def read_table_fits(
     unit_parse_strict="warn",
     mask_invalid=True,
     strip_spaces=False,
+    use_fsspec=None,
+    fsspec_kwargs=None,
 ):
     """
     Read a Table object from an FITS file.
@@ -186,6 +186,20 @@ def read_table_fits(
         Strip trailing whitespace in string columns, default is False and will be
         changed to True in the next major release. This is deactivated when
         using ``memmap=True`` (see above).
+    use_fsspec : bool, optional
+        Use `fsspec.open` to open the file? Defaults to `False` unless
+        ``name`` starts with the Amazon S3 storage prefix ``s3://`` or the
+        Google Cloud Storage prefix ``gs://``.  Can also be used for paths
+        with other prefixes (e.g., ``http://``) but in this case you must
+        explicitly pass ``use_fsspec=True``.
+        Use of this feature requires the optional ``fsspec`` package.
+        A ``ModuleNotFoundError`` will be raised if the dependency is missing.
+    fsspec_kwargs : dict, optional
+        Keyword arguments passed on to `fsspec.open`. This can be used to
+        configure cloud storage credentials and caching behavior.
+        For example, pass ``fsspec_kwargs={"anon": True}`` to enable
+        anonymous access to Amazon S3 open data buckets.
+        See ``fsspec``'s documentation for available parameters.
 
     """
     if isinstance(input, HDUList):
@@ -249,7 +263,13 @@ def read_table_fits(
             mask_invalid = False
             strip_spaces = False
 
-        hdulist = fits_open(input, character_as_bytes=character_as_bytes, memmap=memmap)
+        hdulist = fits_open(
+            input,
+            character_as_bytes=character_as_bytes,
+            memmap=memmap,
+            use_fsspec=use_fsspec,
+            fsspec_kwargs=fsspec_kwargs,
+        )
 
         try:
             return read_table_fits(
@@ -259,6 +279,8 @@ def read_table_fits(
                 unit_parse_strict=unit_parse_strict,
                 mask_invalid=mask_invalid,
                 strip_spaces=strip_spaces,
+                use_fsspec=use_fsspec,
+                fsspec_kwargs=fsspec_kwargs,
             )
         finally:
             hdulist.close()
@@ -356,9 +378,7 @@ def read_table_fits(
     # TODO: implement masking
 
     # Decode any mixin columns that have been stored as standard Columns.
-    t = _decode_mixins(t)
-
-    return t
+    return _decode_mixins(t)
 
 
 def _encode_mixins(tbl):
@@ -436,7 +456,7 @@ def _encode_mixins(tbl):
     return encode_tbl
 
 
-def write_table_fits(input, output, overwrite=False, append=False):
+def write_table_fits(input, output, overwrite=False, append=False, name=None):
     """
     Write a Table object to a FITS file.
 
@@ -450,11 +470,14 @@ def write_table_fits(input, output, overwrite=False, append=False):
         Whether to overwrite any existing file without warning.
     append : bool
         Whether to append the table to an existing file
+    name : str
+        Name to be populated in ``EXTNAME`` keyword.
+
     """
     # Encode any mixin columns into standard Columns.
     input = _encode_mixins(input)
 
-    table_hdu = table_to_hdu(input, character_as_bytes=True)
+    table_hdu = table_to_hdu(input, character_as_bytes=True, name=name)
 
     # Check if output file already exists
     if isinstance(output, (str, os.PathLike)) and os.path.exists(output):
